#
# spec file for package inkscape
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _version 1.3.2_2023-11-25_091e20ef0f

Name:           inkscape
Version:        1.3.2
Release:        3.2
Summary:        Vector Illustration Program
License:        GPL-3.0-only
URL:            https://inkscape.org/

Source:         https://inkscape.org/gallery/item/44615/inkscape-%{version}.tar.xz#/inkscape-%{_version}.tar.xz
# openSUSE palette file
Source1:        openSUSE.gpl
Source2:        inkscape-split-extensions-extra.py
Source98:       https://media.inkscape.org/media/resources/sigs/inkscape-%{_version}.tar.xz.sig
Source99:       https://inkscape.org/~MarcJeanmougin/gpg#/%name.keyring

# PATCH-FIX-UPSTREAM https://gitlab.com/inkscape/inkscape/-/merge_requests/6209
Patch0:         inkscape-poppler-24.03.0.patch
# PATCH-FIX-UPSTREAM
Patch1:         https://gitlab.com/inkscape/inkscape/-/merge_requests/6089.patch#/inkscape-libxml2.12.patch

BuildRequires:  cmake
BuildRequires:  double-conversion-devel
BuildRequires:  fdupes
BuildRequires:  gc-devel
%if 0%{suse_version} < 1550
BuildRequires:  gcc10-c++
%else
BuildRequires:  gcc-c++
%endif
BuildRequires:  intltool
BuildRequires:  libboost_filesystem-devel >= 1.75
BuildRequires:  libboost_headers-devel >= 1.75
BuildRequires:  libboost_stacktrace-devel >= 1.75
BuildRequires:  liblcms2-devel
BuildRequires:  libpoppler-glib-devel > 22.01.0
BuildRequires:  libxslt-devel
BuildRequires:  ninja
BuildRequires:  perl
BuildRequires:  pkgconfig
BuildRequires:  popt-devel
BuildRequires:  potrace-devel
BuildRequires:  python3-devel
BuildRequires:  python3-gobject-devel
BuildRequires:  python3-xml
BuildRequires:  readline-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(2geom) >= 1.3.0
BuildRequires:  pkgconfig(GraphicsMagick++)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(gdl-3.0)
BuildRequires:  pkgconfig(gsl)
BuildRequires:  pkgconfig(gspell-1)
BuildRequires:  pkgconfig(gtkmm-3.0)
BuildRequires:  pkgconfig(libcdr-0.1)
BuildRequires:  pkgconfig(libexif)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(librevenge-0.0)
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(libvisio-0.1)
BuildRequires:  pkgconfig(libwpg-0.3)
# extensions use annotations which requires 3.7+
Requires:       python(abi) >= 3.7
Requires:       python3-gobject
# python3-imaging is generic for python3-Pillow
Recommends:     python3-imaging
Recommends:     python3-lxml
Recommends:     python3-numpy
Recommends:     python3-scour
Recommends:     python3-xml
Obsoletes:      %{name}-extensions-dia < %{version}
Obsoletes:      %{name}-extensions-skencil < %{version}

%description
Inkscape is a vector graphics editor.

%package extensions-extra
Summary:        Additional extensions for Inkscape
Requires:       %{name} = %{version}
# ps_input.py is a wrapper around ps2pdf, which lives in ghostscript package.
Requires:       ghostscript
Requires:       python3-lxml
Requires:       python3-numpy
Requires:       python3-scour
Requires:       python3-xml
Enhances:       %{name}
Supplements:    (%{name} and python3-lxml and python3-numpy and python3-scour and python3-xml)

%description extensions-extra
Extra extensions for Inkscape. Recommended for everybody who wants to
use Inkscape.

Inkscape is a vector graphics editor.

%package extensions-fig
Summary:        Fig import extensions for Inkscape
Requires:       %{name} = %{version}
Requires:       %{name}-extensions-extra = %{version}
Requires:       transfig
Enhances:       %{name}
Supplements:    (%{name} and transfig)

%description extensions-fig
Fig family (XFig, Figurine, JFig, WinFig,...) import extension for
Inkscape.

Inkscape is a vector graphics editor.

%package extensions-gimp
Summary:        GIMP extensions for Inkscape
Requires:       %{name} = %{version}
Requires:       %{name}-extensions-extra = %{version}
Requires:       gimp
Enhances:       %{name}
Supplements:    (%{name} and gimp)

%description extensions-gimp
The GIMP import and export extensions for Inkscape.

Inkscape is a vector graphics editor.

%package extensions-scribus
Summary:        Scribus extensions for Inkscape
Requires:       %{name} = %{version}
Requires:       %{name}-extensions-extra = %{version}
Requires:       scribus
Enhances:       %{name}
Supplements:    (%{name} and scribus)

%description extensions-scribus
The Scribus-based PDF export extension for Inkscape.

Inkscape is a vector graphics editor.

%lang_package

%prep
%autosetup -n %{name}-%{_version} -p1

%build
%ifarch %{arm}
export LDFLAGS+="-Wl,--no-keep-memory -Wl,--reduce-memory-overheads"
%endif
%if 0%{suse_version} < 1550
export CXX=g++-10
%endif
%cmake \
  -GNinja \
  -DINKSCAPE_INSTALL_LIBDIR=%{_libdir} \
  -DCMAKE_SKIP_RPATH:BOOL=OFF \
  -DCMAKE_SKIP_INSTALL_RPATH:BOOL=OFF \
  -DWITH_MANPAGE_COMPRESSION=OFF \
  -DWITH_DBUS=ON \
  %{nil}
%ninja_build

%install
%ninja_install -C build

# Packaging/distribution info.
rm %{buildroot}%{_datadir}/inkscape/extensions/{LICENSE.txt,MANIFEST.in,README.md,TESTING.md,CONTRIBUTING.md}
# Test framework.
rm %{buildroot}%{_datadir}/inkscape/extensions/tox.ini        \
   %{buildroot}%{_datadir}/inkscape/extensions/.pylintrc      \
   %{buildroot}%{_datadir}/inkscape/extensions/doxygen-main.dox
rm -rf %{buildroot}%{_datadir}/inkscape/extensions/.pytest_cache
# extensions/doc
rm -rf %{buildroot}%{_datadir}/inkscape/extensions/docs
rm %{buildroot}%{_datadir}/inkscape/extensions/{.darglint,.pre-commit-config.yaml,package-readme.md,poetry.lock,pyproject.toml}

install -Dpm 0644 %{SOURCE1} %{buildroot}%{_datadir}/inkscape/palettes/

%find_lang %{name} %{?no_lang_C}

sed -i -e "1 s|#! *%{_bindir}/env python|#!%{_bindir}/python3|" %{buildroot}%{_datadir}/inkscape/extensions/*.py

# Split extensions.
python3 %{SOURCE2} %{buildroot}%{_datadir}/inkscape/extensions "%%{_datadir}/inkscape/extensions/"

%fdupes %{buildroot}

%post -n %{name} -p /sbin/ldconfig

%postun -n %{name} -p /sbin/ldconfig

%files -f inkscape.lst
%{_bindir}/*
%dir %{_libdir}/inkscape
%{_libdir}/inkscape/lib%{name}_base.so
%{_libdir}/inkscape/lib%{name}_base.so.*
%{_datadir}/applications/*Inkscape.desktop
%{_datadir}/icons/hicolor/*/apps/*Inkscape.png
%{_datadir}/icons/hicolor/*/apps/*Inkscape.svg
%{_datadir}/icons/hicolor/*/apps/*Inkscape-symbolic.svg
%{_datadir}/metainfo/*Inkscape.appdata.xml
%dir %{_datadir}/inkscape/
%{_datadir}/inkscape/[cdf-z]*
%{_datadir}/inkscape/examples/
%dir %{_datadir}/inkscape/extensions/
%{_datadir}/inkscape/extensions/svg_fonts/
%{_datadir}/inkscape/extensions/*.xsl*
%{_datadir}/inkscape/extensions/colors.xml
%{_datadir}/inkscape/extensions/Poly3DObjects/
%{_datadir}/inkscape/extensions/alphabet_soup/
%{_datadir}/inkscape/extensions/inkweb.js
%{_datadir}/inkscape/extensions/jessyInk.js
%{_datadir}/inkscape/extensions/jessyInk_core_mouseHandler_noclick.js
%{_datadir}/inkscape/extensions/jessyInk_core_mouseHandler_zoomControl.js
%{_datadir}/inkscape/extensions/jessyink_video.svg
%{_datadir}/inkscape/extensions/fontfix.conf
%{_datadir}/inkscape/extensions/seamless_pattern.svg
%{_datadir}/inkscape/extensions/raster_output_jpg.svg
%dir %{_datadir}/inkscape/extensions/icons
%{_datadir}/inkscape/extensions/icons/businesscard_landscape.svg
%{_datadir}/inkscape/extensions/icons/dvd_box.svg
%{_datadir}/inkscape/extensions/icons/seamless_pattern.svg
%{_datadir}/inkscape/attributes/
%{_datadir}/inkscape/branding/
%dir %{_datadir}/bash-completion/
%dir %{_datadir}/bash-completion/completions/
%{_datadir}/bash-completion/completions/inkscape
%{_mandir}/man1/*.1%{?ext_man}
# We can't really move the localized manpages to the lang package, since they'd
# create a conflict between the lang subpackage and bundles
%dir %{_mandir}/hr/
%dir %{_mandir}/hr/man1/
%dir %{_mandir}/ko/
%dir %{_mandir}/ko/man1/
%{_mandir}/*/man1/*.1%{?ext_man}

%files extensions-extra -f inkscape-extensions-extra.lst
%{_datadir}/inkscape/extensions/output_scour.svg
%{_datadir}/inkscape/extensions/dxf14_*.txt
%{_datadir}/inkscape/extensions/dxf_input_text_scale_factor.svg

%files extensions-fig
%{_datadir}/inkscape/extensions/fig*

%files extensions-gimp
# NOTE: export_gimp_palette* does not depend on gimp, but belongs here logically:
%{_datadir}/inkscape/extensions/*gimp*

%files extensions-scribus
%{_datadir}/inkscape/extensions/*scribus*

%files lang -f %{name}.lang

%changelog
* Thu Apr 18 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Add inkscape-libxml2.12.patch: Fix build with libxml 2.12.
* Fri Mar  8 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Add inkscape-poppler-24.03.0.patch: Fix build with poppler >=
  24.03.0.
* Fri Dec  1 2023 thod_@gmx.de
- Update to version 1.3.2:
  + important bugfix release, fixes a data loss bug in 1.3.1
  + Stars, polygons, spirals, 3D boxes are now saved correctly
  + The data that was lost when saving these shapes,
    can be recovered in 1.3.2 if you manually make an edit:
    To fix all missing shapes at once, you can select all elements
    in all layers (Ctrl + Alt + A, need to unlock them first),
    and move them right and back left again with a press on the arrow keys
  + See the full release notes
    https://inkscape.org/release/inkscape-1.3.2
* Sun Nov 19 2023 thod_@gmx.de
- Update to version 1.3.1:
  + more than 30 crash/freeze fixes
  + a new feature to disable snapping to grid lines
  + a new feature to split text into its letters
  + the Shape Builder tool now creates an appropriate number of nodes
  + PDF files that could not be opened with Inkscape 1.3 can now be opened / imported again
  + See the full release notes
    https://inkscape.org/doc/release_notes/1.3.1/Inkscape_1.3.1.html
* Mon Jul 24 2023 thod_@gmx.de
- Update to version 1.3:
  + Shape Builder Tool for building up shapes on canvas
  + Font Collections
  + Pattern Editor
  + Document Resources Dialog
  + Improved performance thanks to fully asynchronous, multithreaded rendering
  + LPE dialog redesigned
  + Improved On-Canvas Pattern Editing
  + Better PDF import
  + Page margins & bleed
  + Return of Search, opacity & blend modes in Layers & Objects dialog and of an optional persistent snap bar
  + Syntax highlighting in XML Editor
  + See the full release notes
    https://inkscape.org/doc/release_notes/1.3/Inkscape_1.3.html
- Drop patch 0001-Fix-build-with-GCC13.patch, fixed upstream
* Tue May 23 2023 Dirk Stoecker <opensuse@dstoecker.de>
- Add Recommends for python3-imaging (python3-Pillow)
* Tue Mar 21 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add 0001-Fix-build-with-GCC13.patch: Fix build with GCC13.
* Sun Dec 18 2022 thod_@gmx.de
- Update to version 1.2.2:
  + 4 crash fixes, over 25 bug fixes, 5 fixes for extension bugs
    and 13 improved user interface translations
  + 2f3101417.patch merged upstream
  + See the full release notes for Inkscape 1.2.2 at
    https://media.inkscape.org/media/doc/release_notes/1.2.2/Inkscape_1.2.2.html
* Wed Dec  7 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Retain RUNPATH also on Leap 15.4.
* Tue Sep 13 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add 2f3101417.patch: Fix build with Poppler 22.09.0.
* Sat Jul 16 2022 thod_@gmx.de
- Update to version 1.2.1:
  + Important fix for a bug where a loss of data occurred
  + Ensures that objects in multipage documents show up on all pages
  + Fixes 5 crashes, over 25 bugs, 4 extension bugs, 15 improved
    user interface translations, 3 improved documentation translations
  + See the full release notes for Inkscape 1.2.1 at
    https://media.inkscape.org/media/doc/release_notes/1.2.1/Inkscape_1.2.1.html
* Thu Jun  9 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Fix version: it's 1.2, not 1.2.0 (fixes download of upstream
  assets referenced by URL).
* Sat Jun  4 2022 thod_@gmx.de
- Update to version 1.2:
  + Inkscape documents can now hold multiple pages
  + Editable markers and dash patterns
  + Layers and objects dialog merged
  + On-canvas alignment snapping and Snap settings redesign
  + New 'Tiling' Live Path Effect
  + Redesigned Export dialog with preview
  + Import SVG images from Open Clipart, Wikimedia Commons and others
  + Selectable object origin for numerical scaling and moving
  + All alignment options in a single dialog
  + Gradient editing in the Fill and Stroke dialog
  + Gradient dithering
  + SVG Font Editor updated
  + Flowing text around shapes and text padding
  + Convenience Boolean operation for splitting paths
  + Configurable Tool bar
- Drop patches: Fixed upstream
  * Fix_build_poppler_22030.patch
  * Fix_build_poppler_22040.patch
* Fri Apr 22 2022 Christophe Giboudeaux <christophe@krop.fr>
- Add poppler 22.04.0 compability fix:
  * Fix_build_poppler_22040.patch
- Update Fix_build_poppler_22030.patch
* Thu Mar  3 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.1.2:
  + Dependencies updated, fixing bitmap exports
  + Graphic tablet pens erasors switch to the correct tool
  + Fix lost styling of text converted to path
  + Fix relative position of clones pasted to a new document
  + Fix various crashes
- Drop ebc4de4bfe34d6c5f2e27da47f5d62e4de0394fd.patch: Fixed
  upstream.
- Add Fix_build_poppler_22030.patch: Fix build with poppler 22.03.0
* Mon Jan 17 2022 Mykola Krachkovsky <w01dnick@gmail.com>
- Fixed export to DXF14 (boo#1189514).
  Added missing dxf14_*.txt files.
- Removed redundant excludes
* Fri Dec  3 2021 Yifan Jiang <yfjiang@suse.com>
- Enable RPATH in cmake (bsc#1193183, bsc#1193261).
* Tue Nov 30 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Ensure we download the same tarball every time. Also add sig and
  keyring as sources and verify that we have the right one.
* Tue Nov 23 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Add ebc4de4bfe34d6c5f2e27da47f5d62e4de0394fd.patch: Fix build
  with poppler 21.11.0, patch from upstream git.
* Fri Sep 24 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.1.1:
  * Pressure sensitivity should work again in Windows
  * Stroke to path working on text again
  * Startup time improved
  * Fix various crashes
* Thu Jun 17 2021 Antonio Larrosa <alarrosa@suse.com>
- Use gcc10-c++ to build in Leap. gcc7 is too old.
* Mon Jun 14 2021 Antonio Larrosa <alarrosa@suse.com>
- Update to 1.1
  * A Welcome dialog, where the look of Inkscape can be selected,
    and some choices for the new document's size or file to open
    are available
  * A Command palette that opens when the ? key is pressed and
    that allows to search and use many functions without having to
    use a keyboard shortcut or going through the menus
  * It is now possible to copy, cut and paste parts of paths with
    the Node tool
  * The dialog docking system has been rewritten, which resolves
    many issues with Inkscape's docked dialogs and allows you to
    dock dialogs on either side of the screen
  * New Outline Overlay mode that displays object outlines while
    also showing their real colors
  * Preferences options are now easier to find by using the new
    search field
  * It is no longer necessary to remember to click on 'Export' in
    the PNG Export dialog, as the exporting will already happen
    after the click on 'Save' in the file selection dialog.
  * Export as JPG, TIFF, optimized PNG and WebP directly from
    Inkscape
  * When pasting a copied object, Inkscape now pastes it directly
    on top of the currently selected object by default
  * An extension for updating extensions and installing additional
    extensions, called the Extension Manager (currently in beta
    stage)
  * To learn more, see the full release notes for Inkscape 1.1 at
    https://media.inkscape.org/media/doc/release_notes/1.1/Inkscape_1.1.html
- Move dependencies from gtkspell to gspell and from Magic++
  (which was not used since inkscape requires an old version of
  ImageMagick if that library is used) to GraphicsMagic++, also
  add BuildRequires for dbus, readline, libcdr and
  libboost_filesystem-devel
- Drop patch which is already included by upstream:
  * 2790.patch
* Fri Mar 26 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Add 2790.patch: fix build against glib 2.67.3.
* Mon Jan 25 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.0.2
  * Zooming by middle mouse button click (pressing scroll wheel) can
    now be deactivated in Edit → Preferences → Behavior → Steps:
    Zoom with middle mouse click
  * Canvas rotation by Ctrl + middle mouse drag or
    Ctrl + Shift + Scroll can be prevented in two ways:
  - from View → Canvas Orientation → Lock Rotation
  - for all new Inkscape windows in Edit → Preferences → Interface:
    Lock canvas rotation by default
  * fixed a long-standing, very annoying bug where, when copying
    an object to the clipboard while also running certain other
    programs on Linux desktops
  * Stroke to Path: Converting an object's stroke to a path
    no longer makes its clones vanish
  * Performance: Improved rendering performance when zooming
    through multiple zoom levels
  * CSS: CSS classes that start with a letter that isn't part of
    the ASCII set are no longer ignored
  * User interface: Random actions should no longer cause sudden
    scaling of the canvas
  * Arcs from Inkscape files created with versions older than 1.0
    are no longer rendered as slices
  * A long-standing issue with the Eraser tool painting red lines
    0instead of erasing as soon as the user has interacted with
    a menu or dialog or another user interface element has been fixed
  * Lots of other minor fixes
- Drop inkscape-include-atomic.patch
* Mon Nov  2 2020 Michael Gorse <mgorse@suse.com>
- Switch to ninja; probably fixes intermittent build failure
  (bsc#1177208).
* Fri Oct  2 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Clean up constraints:
  * Remove ppc64le specific memory bound, use global 4GB limit.
  * Add memoryperjob constraint, some ppc64{,le} workers have
    a high core-to-memory ratio.
* Tue Sep  8 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.0.1:
  * Selectors/CSS dialogue is now available.
  * Experimental colour-managed PDF export through Scribus.
  * Many crash fixes and bugs fixed.
- Add a inkscape-extensions-scribus package with the new extension.
* Mon Aug 24 2020 Martin Liška <mliska@suse.cz>
- Enable again LTO. It should work now.
* Mon Aug 24 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Add inkscape-include-atomic.patch: Fix build with Boost 1.74,
  where we can no longer rely on boost bringing the atomic header
  into the game.
* Thu Jun 11 2020 Michel Normand <normand@linux.vnet.ibm.com>
- Add memory limit _constraints for ppc64le to avoid oom build failure
* Thu May  7 2020 thod_@gmx.de
- Fix inkscape-split-extensions-extra.py for older python versions.
* Mon May  4 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.0:
  * See https://inkscape.org/release/inkscape-1.0/
- Re-enable ImageMagick support.
- Replace inkscape-split-extensions-extra.sh with
  inkscape-split-extensions-extra.py, adapting for 1.0.
- Add python3-numpy and python3-scour to the list of extra
  dependencies as only extra extensions need them.
- Stop altering Name and GenericName from the .desktop file:
  original values are fine.
- Remove
  0001-Run-python-script-for-translations-with-Python-3.patch:
  merged upstream.
- Remove build_internal_libraries_as_static.patch: merged upstream.
- Remove f5e0ea893f34_extensions_python3_compatibility.patch:
  merged upstream.
- Remove fix_install_targets.patch: fixed upstream.
- Remove inkscape-fix-for-poppler-0.76.patch: merged upstream.
- Remove inkscape-fix-for-poppler-0.82.patch: merged upstream.
- Remove inkscape-fix-for-poppler-0.83.patch: merged upstream.
- Remove inkscape-packages.patch: no longer needed.
- Remove mr_568_extensions_python3_compatibility.patch: merged
  upstream.
- Remove mr_582_extensions_python3_compatibility.patch: merged
  upstream.
- Remove obsolete hacks from the spec file and add new ones.
- Remove the inkscape-extensions-dia and
  inkscape-extensions-skencil packages: the extensions were
  removed upstream.
- Drop the python2 bcond, no practical use without skencil.
- Drop openSUSE versions prior to Leap 15.x.
* Thu Apr 16 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Fixup files sections for sk1 exclusion.
* Wed Apr  8 2020 Tomáš Chvátal <tchvatal@suse.com>
- Remove sk1 depending extension as sk1 is py2 only
  * Keep conditioned so it will stay on Leap 15 if backported
* Thu Dec  5 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Add inkscape-fix-for-poppler-0.83.patch: Fix build with poppler
  0.83 and newer.
- Update URL to new homepage.
* Sat Nov  2 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Add backported inkscape-fix-for-poppler-0.82.patch: Fix build
  with poppler 0.82 and newer.
- Stop post(un) handling of desktop_database_post(un) and
  icon_theme_cache_post(un) macros, no longer needed for any
  supported version of openSUSE.
* Tue Jul 30 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Change Python dependencies to Python 3 as Python 2 will be EOL in 2020.
- Use Python 3 to extract translations, add
  0001-Run-python-script-for-translations-with-Python-3.patch
- Make extensions compatible with Python 3
  (https://bugs.launchpad.net/inkscape/+bug/1735363)
  * Add mr_568_extensions_python3_compatibility.patch
  * Add f5e0ea893f34_extensions_python3_compatibility.patch
  * Add mr_582_extensions_python3_compatibility.patch
- Some spec cleanups (buildroot, defattr)
- Require extensions-extra for gimp extension
* Fri May 31 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Add inkscape-fix-for-poppler-0.76.patch: Fix build with poppler
  0.76, patch from upstream git.
* Wed May 15 2019 Martin Liška <mliska@suse.cz>
- Disable LTO (boo#1135211).
* Sun Jan 20 2019 seanlew@opensuse.org
- Update to version 0.92.4
  * Align multiple objects as a group relative to a single object
  * Write image data to stdout and read from it
  * Experience extensions working faster within complex docs
  * See improved speed when deselecting a path with many nodes
  * Ungroup text elements won't result in changed font size
  * Able to print and/or print correct paper size with printers
  * See improved perf of the measure tool when grids are visible
  * See proper opacity of partially transparent embedded bmp imgs
  * Able to Shift/Ctrl-click on control handles of shapes w/o crash
  * Build Inkscape with up-todate- poppler library 0.72.0
* Tue Dec 18 2018 bjorn.lie@gmail.com
- Update to version 0.92.3+20181214.6afa35c3d3:
  * fix poppler 0.72.0 build
  * Remove nullptr not used in some system
  * Backport from trunk. Add filter render in 1 pass and remove
    banding on filters
* Mon Dec  3 2018 bjorn.lie@gmail.com
- Update to version 0.92.3+20181125.5aff6bad34:
  * Backport from master, Fix bug 1804946: Measurement tool is very
    slow when using grids This move from Namedview to a new
    prefernes value of type point to not reload full namedvies/grid
    on meassure
  * CMake: Do not override CMAKE_<LANG>_LINK_EXECUTABLE variables
  * CMake: Specifically enable Microsoft bit-field layout for
    structs
  * CMake/MSYS2: Add new dependency of libtiff (libzstd)
  * Fix build with poppler-0.71.0
  * Fix encoding of "title" label in win32 native file dialog
  * ShapeEditor: Always keep KnotHolders in set_item()
  * CI: Fix wrong path in docker registry for 14.04
  * CI: Make ccache and -std=c++98 actually work with old CMake
  * Fix code incompatible with old gcc / C++ < 11
- Switch to source service checkout from stable branch.
- Drop Fix-compilation-poppler-0_65.patch: Fixed upstream.
* Mon Jul  9 2018 bjorn.lie@gmail.com
- Add yet a commit from upstream to fix build with new poppler.
* Mon Jul  9 2018 bjorn.lie@gmail.com
- Add Fix-compilation-poppler-0_65.patch: Fix compilation with
  poppler 0.65.0 and newer. Replace unused includes with one that
  is actually used (lp#1772883).
* Sat Jun  2 2018 bjorn.lie@gmail.com
- Drop optional gnome-vfs2-devel BuildRequires: No longer strickly
  needed, and obsolete upstream.
* Mon Apr 30 2018 jengelh@inai.de
- Update summaries. Trim filler words from descriptions.
* Wed Apr 25 2018 stefan.bruens@rwth-aachen.de
- Omit translations from appdata on Leap 42.x/SLE12, merging
  translations in XML requires msgfmt >= 0.19.7
* Tue Apr 24 2018 stefan.bruens@rwth-aachen.de
- Update to 0.92.3, a stability and bugfix release
  * new CLI options --export-area-{drawing,page}, --export-margin
  * Text tool, switching between RTL/LTR writing
  * Circle/Ellipse tool, toolbar fields for Rx, Ry radius
  * PDF+LaTeX export, basic linespacing support
  * Preferences option for number of rendering tiles
  * Various bug fixes, for details see:
    https://inkscape.org/en/release/0.92.3/
- Drop obsolete inkscape-poppler058-fix.patch
- Use cmake instead of autoconf
  * Add build_internal_libraries_as_static.patch
  * Add fix_install_targets.patch
- Spec file cleanup
  * Remove conditionals for EOLed distributions
  * Remove ghostscript-fonts-std dependency
  * Add libjpeg build dependency
  * Do not package extension unittests
  * Move all extensions with ghostscript or pstoedit dependency
    to extensions-extra subpackage
- Correct License, original inkscape code is GPL-2.0 or later, but
  the binary contains code from Gimp (GPL-3.0), see COPYING
* Wed Mar  7 2018 guoyunhebrave@gmail.com
- Add python-scour Recommends, used to clean up and minify SVG.
* Fri Dec  8 2017 dimstar@opensuse.org
- Add explicit python2-xml BuildRequires: the ./i18n.py script,
  executed during build, imports xml and we are thus responsible to
  have the dependencies in place.
* Mon Oct  9 2017 dmueller@suse.com
- remove env shebang from inkscape extensions subpackage
* Sat Sep 23 2017 plinnell@opensuse.org
- Disable IM7 until upstream supports it
- Resolves: https://bugzilla.suse.com/show_bug.cgi?id=1059927
* Sat Sep 23 2017 zaitor@opensuse.org
- Rebase inkscape-poppler058-fix.patch: Add yet an upstream commit.
* Fri Sep 15 2017 zaitor@opensuse.org
- Add inkscape-poppler058-fix.patch: Adapt to poppler 0.58, patch
  from upstream git (lp#1715820).
* Fri Aug 18 2017 plinnell@opensuse.org
- drop inkscape-gcc7-buildfix.patch
* Fri Aug 11 2017 pgajdos@suse.com
- do not require aspell, require gtkspell [bsc#1052953]
* Mon Aug  7 2017 plinnell@opensuse.org
- Update to version 0.92.2:
  + Stability and bug fix release. Several crash bugs fixed.
  + No change log, changes here:
  https://launchpad.net/inkscape/+milestone/0.92.2
* Wed May 17 2017 dimstar@opensuse.org
- Add inkscape-gcc7-buildfix.patch: Fix C++11 errors and warnings
  with g++-7.
* Mon Mar 20 2017 mliska@suse.cz
- Update to version 0.92.1:
  + Text: baseline-spacing related issues with regular and flowed text in legacy Inkscape SVG files (Bug #1655483 and others)
  + Text: Default baseline spacing stored in relative units is always converted to document units (Bug #1645016)
  + Path effects: Crash on ungroup if group contains elements with path effects (Bug #1657591)
  + Clipboard: Pasting a path effect from clipboard fails (Bug #1656093)
  + Clipboard: Fix copy&pasting of groups which contain elements with path effects (Bug #1656527)
  + Selection: Node tool can selected objects on locked layers (Bug #1656141)
  + Clones: Critical warnings with clones and symbols (Bug #1653184)
  + About screen missing for several UI languages (Bug #1659426)
  + Selection: Missing transformation handles after reset of rotation center (Bug #1657874)
  + Bitmap images: Crash when opening files with invalid image links (Bug #1660142)
  + Bitmap images: Fix path separators in relative image links (Windows) (Bug #1659347)
  + File import: Failure to open CDR/Visio/WPG files from paths with special characters (Windows) (Bug #1656763)
* Tue Feb 14 2017 src@posteo.de
- buildrequire potrace-devel for tracing bitmaps.
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Mon Jan  9 2017 robby.engelmann@igfs-ev.de
- update to version 0.92:
  + Mesh Gradients are now supported.
  + Many SVG2 and CSS3 properties are now supported (e.g. paint-order, mix-blend-mode). Not all are available from the GUI.
  + The new Object dialog allows to select, label, hide and lock any object in the drawing from a dialog that lists them all
  + Selection sets make it possible to 'group' objects together regardless of document structure
  + Several new path effects have been added, among them Envelope/Perspective, Lattice Deformation, Mirror and Rotate Copies
  + There are several new extensions (e.g. a seamless pattern extension) and a new filter (colorblindness simulation) included in the release, many old extensions have been updated or got new features
  + Spray tool and measure tool received a set of nifty new features
  + Interactive smoothing for lines created with the Pencil tool
  + BSplines (and more) are available for the Pen tool
  + Checkerboard background can be used to more easily see object transparencies
  + see http://wiki.inkscape.org/wiki/index.php/Release_notes/0.92 for full changelog
- Drop upstream included patches:
  + inkscape-remove-datetime.patch
  + inkscape-cache-fix.patch
  + inkscape-appdata.patch
- Rebased patch
  + inkscape-packages.patch
* Tue Jul 26 2016 badshah400@gmail.com
- Add inkscape-appdata.patch to install a translated appdata file;
  patch touches autotools build files, run autoreconf before
  configure.
* Fri Jun 24 2016 zaitor@opensuse.org
- Export -std=c++11 in CXXFLAGS, needed now after removal of patch
  in libsig++ forcing the flag previously. May be removed when
  lp#1488079 is fixed.
* Wed Mar 23 2016 aeszter@gwdg.de
- Add inkscape-cache-fix.patch: Fix bnc#972343
* Tue Mar  8 2016 dimstar@opensuse.org
- Pass --disable-strict-build to configure: allow to build against
  recent glibmm2 versions with deprecated symbols.
* Sat Jan 31 2015 mailaender@opensuse.org
- Update to version 0.91:
  + Improved performance. The new renderer is significantly faster
    on most drawings.
  + OpenMP multithreading for filters.
  + Substantial memory savings.
  + Responsiveness improvements.
  + Rendering bug fixes. The following things now render correctly:
  - Pattern fills (no more gaps between tiles, regardless of
    transformation).
  - Stroke of transformed objects in patterns.
  - Patterns containing clipped objects.
  - Nested clipping paths.
  - Masked and clipped objects with large masks / clipping paths
    in Outline view.
  - Paths with wide strokes and long miters.
  - Fonts.
  + A grayscale display color mode has been added, that shows a
    preview of your drawing in grayscale.
  + The tool control bar for the Node Tool features a new dropdown
    to insert new nodes on the selected segments extreme values.
  + The Measurement tool is a new feature for the artist to measure
    the elements in their drawing.
  + Text size default unit is now points (pt) and is customizable
    (px,pt,pc,mm,cm,in,em).
  + Text toolbar shows full list of font style variants for that
    font.
  + Files with text in em units read correctly.
  + Font substitution warning dialog.
  + Gradient toolbar enhanced to select and modify gradient stops,
    invert, repeat, and link gradients.
  + On-canvas gradient editing fixes: double clicking to create
    stops, correct focus on select.
  + Gradients sortable by color, name and usage in Fill/Stroke.
  + Gradients can be renamed in Fill/Stroke.
  + New Find/Replace dialog can operate on text or any attribute.
  + Drag and drop to reorder layers and create sublayers.
  + Show/Hide All layers options in context menu.
  + Inkscape has a new Symbols dialog.
  + Visio Stencil files (.vss) can also be used by dropping them in
    the same symbols directory.
  + See http://wiki.inkscape.org/wiki/index.php/Release_notes/0.91
    for a full list of changes.
- Drop upstream fixed patches:
  + inkscape-return-on-exit.patch
  + inkscape-apply-invert-transform.patch
  + inkscape-0.48.5-librevenge.patch
  + inkscape-fix-build-with-poppler-0.29.patch (r13685)
  + inkscape-gc-detection.patch (r12155)
- Rebase inkscape-packages.patch.
- Add pkgconfig(libexif) BuildRequires: enable EXIF support.
- Add aspell-devel BuildRequires: enable spell checking support.
- Add pkgconfig(libcdr-0.1) and pkgconfig(libvisio-0.1)
  BuildRequires: support for more image formats.
- Add pkgconfig(dbus-glib-1) BuildRequires: new dependency.
- Remove docbook-toys and sgml-skel BuildRequires: no longer
  needed.
* Mon Jan  5 2015 dimstar@opensuse.org
- Add inkscape-gc-detection.patch: Use pkg-config to detect bdw-gc.
* Mon Dec 29 2014 mlin@suse.com
- Add inkscape-fix-build-with-poppler-0.29.patch: Fix build with
  poppler 0.29. Patch has been backported from
  https://bugs.launchpad.net/inkscape/+bug/1399811.
* Sat Nov 22 2014 stefan.bruens@rwth-aachen.de
- make inkscape-split-extensions-extra script more robust
  (comments, 'as' keyword, leading/trailing whitespace)
* Tue Jul 22 2014 fstrba@suse.com
- Add inkscape-0.48.5-librevenge.patch:
  + Port the WPG importer to librevenge framework based libwpg.
- Add autoconf, automake and libtool BuildRequires and call
  libtoolize and autorecof: regenerate the build system, as above
  patch touches the build system.
- Update BuildRequires, following the port:
  + Remove libwpg-devel
  + Add pkgconfig(libwpg-0.3) and pkgconfig(librevenge-0.0).
- Run osc service localrun clean_spec_file on the package
* Tue Jul 22 2014 fcrozat@suse.com
- Add _constraints file to require at least 5G disk space to fix
  spurious rebuild issues.
* Fri Jul 11 2014 dimstar@opensuse.org
- Update to version 0.48.5:
  + Adobe Illustrator SVG files containing entities can be loaded
    again.
  + Support for Poppler 0.26.
  + Support for Boehm-GC 7.4.0 and later.
  + Several crash bugs were fixed.
  + 64-bit compilation is now possible on Windows.
- Drop upstream included patches:
  + inkscape-gcc48-buildfix.patch.
  + inkscape-use-recommended-freetype-include.patch.
  + bug-1315142-patch-src_extension_internal_pdfinput_pdf-parser_cpp-r13333-v2.diff.
* Tue May 13 2014 coolo@suse.com
- Pick
  bug-1315142-patch-src_extension_internal_pdfinput_pdf-parser_cpp-r13333-v2.diff
  Port to poppler-0.26 (lp#1315142).
* Mon Apr 28 2014 schwab@linux-m68k.org
- Don't strip '-g' from RPM_OPT_FLAGS on arm.
* Wed Dec 11 2013 hrvoje.senjan@gmail.com
- Add inkscape-use-recommended-freetype-include.patch: Freetype
  upstream recommends using their macros together with ft2build.h
  include. Positive sideeffect is that this patch makes it build
  with both freetype2 2.5.1, and older versions.
* Mon Jun 24 2013 cgiboudeaux@gmx.com
- Add inkscape-gcc48-buildfix.patch: Fix build with GCC 4.8
  (lp#1095364).
* Mon Dec 17 2012 dimstar@opensuse.org
- Update to version 0.48.4:
  + Important bugfixes:
  - A security bug was fixed.
  - Some major bugs causing crashes when using extensions or the
    filters editor were fixed.
  - A bug affecting the outline mode was fixed.
  - Inkscape can now be built on platforms with new versions of
    the Poppler library (v0.20 and higher). (lp#1005565)
  - Relative path names can be used again on the command line for
    EPS/PS and other file types handled by script extensions
    (lp#695120)
  + Updated translations.
- Drop inkscape-poppler20.patch: fixed upstream.
- Drop inkscape-libpng15.patch: fixed upstream.
* Wed Oct  3 2012 pgajdos@suse.com
- build also with libpng15
  * libpng15.patch
* Fri Sep 14 2012 dmueller@suse.com
- Reduce memory usage during linking on ARM to let the build
  succeed.
* Wed Sep 12 2012 malcolmlewis@opensuse.org
- Add inkscape-apply-invert-transform.patch: Apply invert
  transform to all image tags (bnc#779560 lp#840625).
* Wed Jul 18 2012 dimstar@opensuse.org
- Explicitly add ps2pdf-ext.py to the -extras package. This used to
  be caught by the extras-split script, but due to the change of
  this extensions to be a simple wrapper around ps2pdf from
  ghostscript, it's missed (bnc#772085).
- Add ghostscript Requires to the -extra package, as otherwise
  ps2pdf-ext.py won't work at all.
* Fri Jun 15 2012 coolo@suse.com
- yudit is in non-free now (due to openmotif requirement), so do
  not require it
* Wed Jun  6 2012 badshah400@gmail.com
- Add inkscape-poppler20.patch for openSUSE > 12.1 to fix errors
  when building with poppler = 0.20.0; fixes build failures in
  Factory.
* Wed May 16 2012 dimstar@opensuse.org
- Add inkscape-return-on-exit.patch: Return non-zero values in case
  of errors. Patch has been accepted and merged by upstream.
  [bnc#758275, lp#993500].
* Fri Feb 24 2012 vuntz@opensuse.org
- Update to version 0.48.3.1:
  + Bug fixes.
- Changes from version 0.48.3:
  + Regression fixes:
  - Pre-0.46 grids are now correctly imported (lp#221040)
  + Important bugfixes:
  - Clipped and masked objects are selected correctly (lp#365458)
  - The units feet and picas are now correctly handled for grids
    (lp#885500)
  - The grid origin is moved when resizing the page (e.g. when
    clicking clicking "Fit page to selection") (lp#240689)
  - The emphasized grid lines of the axonometric grid now move
    properly according to the origin of the grid.
  + Other bugs fixed: lp#167419, lp#168417, lp#168942, lp#184341,
    lp#239430, lp#298528, lp#340123, lp#341866, lp#386237,
    lp#403421, lp#407394, lp#408566, lp#479644, lp#487144,
    lp#494722, lp#496793, lp#602005, lp#612882, lp#623660,
    lp#663667, lp#668895, lp#681262, lp#693010, lp#721424,
    lp#721448, lp#725063, lp#786667, lp#788560, lp#789122,
    lp#791709, lp#805095, lp#810503, lp#812413, lp#812497,
    lp#819209, lp#821435, lp#824221, lp#829947, lp#834721,
    lp#837603, lp#837799, lp#845354, lp#858369, lp#869019,
    lp#884368, lp#885324, lp#887539, lp#888793, lp#889172,
    lp#898538, lp#900854, lp#902054, lp#907157, lp#909783,
    lp#909958, lp#910463, lp#910467, lp#910479, lp#911079,
    lp#911123, lp#915329, lp#917544, lp#919728, lp#923241,
    lp#933831.
  + Updated translations.
- Change liblcms-devel BuildRequires to liblcms2-devel, to build
  against lcms2.
- Drop inkscape-glib-2.31.patch: fixed upstream.
- Add some automatic detection of localized man pages in %%install,
  so that we don't have to list all new translations manually.
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Thu Dec  1 2011 dimstar@opensuse.org
- Add inkscape-glib-2.31.patch: Fix build with glib 2.31.
* Wed Jul 13 2011 mrdocs@opensuse.org
- Update to version 0.48.2:
  + many crash/hang fixes
  + DXF and tex export fixes
  + Bugs fixed: https://launchpad.net/inkscape/+milestone/0.48.2
  + Updated translations.
- Drop inkscape-0.48.0-gcc46.patch: fixed upstream.
* Tue Mar 22 2011 idoenmez@novell.com
- Add inkscape-0.48.0-gcc46.patch: fix compilation with gcc 4.6
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Mon Jan 31 2011 mrdocs@opensuse.org
- Update to version 0.48.1:
  0.48.1 is a stability and bugfix release.
  + Many small regressions in the node tool were fixed.
  + Exporting of masks has been substantially improved in all
    Cairo-based output formats.
  + lp#544599, lp#591986, lp#605575: Several crash bugs in the node
    tool have been fixed.
  + lp#627134: Rulers are redrawn properly with recent versions of
    GTK
  + lp#675309: Unlinking an orphaned clone no longer causes a crash
  + lp#482993: Problems with extensions sometimes not working at
    all on Mac OS X.
  + lp#651678: Inkscape should no longer crash due to missing icons
    at startup  or when opening the document properties dialog.
  + lp#680520: Shift-clicking on the top rounding handle of a
    rectangle will no longer cause a crash.
  + lp#676271: Inkscape builds correctly with recent Poppler.lp
  + Bugs fixed: lp#658055, bnc#661370
- drop inkscape-r9710-9712.patch: fixed upstream.
- export CFLAGS, as inkscape is C and C++
- Remove --enable-inkboard from configure: jessyink replaces it
- Remove Obsoletes: sodipodi NLD9 is obsolete
- Delete installed but useless header files
- run spec-cleaner on the spec file
* Tue Dec 14 2010 vuntz@opensuse.org
- Fix the build again: the te_IN translation should simply be te,
  so move the translation.
* Sat Dec 11 2010 vuntz@opensuse.org
- Add popt-devel BuildRequires to fix the build.
* Tue Dec  7 2010 vuntz@opensuse.org
- Tag localized man pages with the right language. We should
  eventually move them to the lang subpackage, but at the moment,
  they would create a file conflict between bundles and the lang
  subpackage.
* Tue Nov 30 2010 vuntz@opensuse.org
- Make inkscape-extensions-extra depend on python-xml instead of
  pyxml: pyxml will be removed, and we really wanted to use
  python-xml anyway.
- Update inkscape-packages.patch to mention python-xml instead of
  pyxml: even if upstream mentions pyxml, python-xml is really okay
  here.
* Sun Aug 15 2010 dimstar@opensuse.org
- Update to version 0.48.0:
  + multipath editing
  + improved text tool: subscript, superscript,numerical input for
    text kerning, tracking and more
  + new Airbrush tool
  + LaTeX export with PDF/PS/EPS
  + JessyInk extension to create presentations
  + numerous bugfixes
- Rebase inkscape-remove-datetime.patch.
- Drop inkscape-poppler-0.12.2.patch, inkscape-gcc45.patch and
  inkscape-non_void.patch: upstream fixed.
- Add inkscape-r9710-9712.patch to fix node editor crash when
  dragging near the last node of a path.
* Mon Jun 14 2010 vuntz@opensuse.org
- Do not add wrong categories to inkscape.desktop (Office,
  FlowChart).
* Tue Mar  2 2010 dimstar@opensuse.org
- Add inkscape-gcc45.patch to fix build with gcc 4.5. Patch
  copied from upstream bug tracker, lp#522327.
- Add inkscape-non_void.patch, cross-ported from gdl upstream,
  commit 40b8cb7.
* Wed Dec 16 2009 vuntz@opensuse.org
- Add inkscape-poppler-0.12.2.patch to fix build with recent
  poppler. This patch comes from Fedora, but was not committed
  upstream. See lp#487038 for the discussion, and another patch.
* Fri Nov 27 2009 dimstar@opensuse.org
- Update to version 0.47:
  + Timed autosave: no more lost work
  + Spiro splines: an exciting new way to work with paths, fully
    supported in Pen, Pencil, and Node tools
  + Auto smooth nodes: a new type of node that keeps the path as
    smooth as possible as you move it or its neighbors
  + New modes in Tweak tool: pushing and jittering whole objects,
    scaling/rotating objects, deleting and duplicating using the
    "soft brush"
  + Reworked, much more usable snapping system and a Snapping
    toolbar
  + New path effects, including sketch, hatching, envelope
    deformation: effects can be stacked and assigned to groups
  + A huge collection of preset filters in the new Filters menu
  + New cairo-based PS and EPS export: improved quality, more
    features supported, fallback rasterization for filters and
    transparency
  + Spell checker for text objects in a document
  + Many new extensions: restacking, calendar, printing marks,
    cartesian and polar grids, interpolating attributes
  + Optimized SVG code options, now with their own Preferences page
  + Many other improvements, usability tweaks, memleak stops, and
    misc bugfixes
- Drop patches: inkscape-automake111.patch, inkscape-gcc44.patch,
  inkscape-gtk-clist.patch, inkscape-lp237574-poppler.patch,
  inkscape-polyutil-newpoly.patch, inkscape-warnings.patch,
- Rebased patches: inkscape-packages.patch and
  inkscape-remove-datetime.patch.
- No longer patch configure.ac during %%setup.
- Add gsl-devel BuildRequires.
- Added openSUSE palette file to the package (openSUSE.gpl).
- Do not provide sodipodi; version Obsoletes for sodipodi.
  Fixes a rpmlint warning.
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Mon Jul 13 2009 coolo@novell.com
- remove dupliacted files (fix build with automake 1.11)
* Wed May 13 2009 vuntz@novell.com
- Remove unneeded BuildRequires: libglade2-devel,
  libgnomeprintui-devel, libgnomeui-devel, libwnck-devel,
  loudmouth-devel
- Add BuildRequires: gc-devel, gnome-vfs2-devel
- Do not build gc inside this package and use the system-installed
  one. Drop gc6.4.patch since we don't need to patch gc now :-)
- Drop inkscape-boehm-gc.patch: we just use the system-installed gc
  now.
- Drop inkscape-swigfix.patch: I don't really see the point of
  this.
- Drop inkscape-bug-189159.patch: the change is actually wrong,
  looking at the code...
- Drop inkscape-configure.patch: not needed anymore.
- Drop inkscape-buffer-overrun.patch: doesn't appear to be needed
  anymore.
- Tag inkscape-polyutil-newpoly.patch
- Remove non-existing --enable-db2html, --enable-gnome,
  - -with-gnome-print and --with-gc configure options.
- Use makeinstall.
- Do not package some files twice.
* Tue Apr 28 2009 vuntz@novell.com
- Add inkscape-gcc44.patch to fix build with gcc 4.4.
* Fri Apr  3 2009 vuntz@novell.com
- Remove python-numeric Requires: there's no reference to it
  anywhere in the code, so it wasn't needed.
* Fri Mar 27 2009 vuntz@novell.com
- Add inkscape-remove-datetime.patch to be more build-compare
  friendly.
* Sun Jan 25 2009 vuntz@novell.com
- Use sr@latin instead of sr@Latn since it's what glibc upstream
  uses.
* Fri Oct  3 2008 vuntz@novell.com
- Add inkscape-lp237574-poppler.patch to compile with poppler in
  Factory.
* Wed Sep 24 2008 sbrabec@suse.cz
- Require and supplement correct resolvables for gimp.
* Tue Jul  1 2008 sbrabec@suse.cz
- Added missing dependencies: libMagick++-devel, libwpg-devel,
  gimp, transfig, yudit.
- Packaged extensions using pyxml, lxml and yudit as an extra
  package to shrink mandatory dependencies and not break plugins.
  Uses an extra script for evaluation.
- Packaged optional dia, fig, gimp and skencil plugins as separate
  packages with extra dependencies.
- Removed dependency on skencil, no more needed for EPS import
  (bnc#394748).
- Removed dependency on libwmf, no more needed for WMF import.
- Tell user about pyxml and lxml packages instead of suggestinng of
  compilation from source (however the message should not appear).
* Fri Jun 27 2008 maw@suse.de
- Add inkscape-gtk-clist.patch, to enable building against
  recent versions of gtk+.
* Thu May 15 2008 maw@suse.de
- Recommend python-lxml (bnc#370334).
* Wed May  7 2008 maw@suse.de
- Respin inkscape-warnings.patch.
* Thu Apr  3 2008 maw@suse.de
- Buildrequire libpoppler-glib-devel, thereby enabling pdf import support
  (bnc#376752).
* Fri Mar 28 2008 maw@suse.de
- Update to version 0.46:
  + Many new features and bugfeatures
  + For a detailed account of what's new, see the NEWS file
- Remove stale patches: inkscape-invalid-conversion.patch,
  inkscape-0.45.1-gcc43.patch, inkscape-g_assert.patch
- Respin inkscape-bug-189159.patch
- Add inkscape-warnings.patch
- Rename sr@latin to sr@Latn.
* Thu Mar  6 2008 maw@suse.de
- Fix the build when against newer versions of intltool.
* Tue Feb  5 2008 maw@suse.de
- Disable perl support for now.
* Mon Jan 28 2008 maw@suse.de
- Add inkscape-g_assert.patch.
* Fri Jan 11 2008 coolo@suse.de
- take more gcc43 patches from SVN
* Sat Nov 10 2007 mauro@suse.de
- Added inkscape-0.45.1-gcc43.patch
  + Fixes issues with gcc 4.3.
* Tue Aug  7 2007 maw@suse.de
- Use %%fdupes
- Split off a -lang subpackage.
* Thu May 10 2007 prusnak@suse.cz
- recommends pyxml [#271758]
* Wed Apr 18 2007 aj@suse.de
- Fix spec list so that package builds again.
* Thu Mar 29 2007 maw@suse.de
- Update to version 0.45
- Remove upstreamed inkscape-siox-max.patch
- Remove now-unnecessary inkscape-session-manager-strcmp.patch and
  inkscape-enable-perl.patch
- Add inkscape-buffer-overrun.patch
* Wed Jan 31 2007 sbrabec@suse.cz
- Removed remaining references to /opt/gnome (#240571).
* Tue Jan 23 2007 prusnak@suse.cz
- fixed build errors
  * polyutil-newpoly.patch - uninitialized structure
  * session-manager-strcmp.patch - comparing char* w/ string literal
* Mon Jan 22 2007 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Thu Jan  4 2007 prusnak@suse.cz
- fixed illegal comparison (siox-max.patch) [#231224]
* Mon Nov  6 2006 jhargadon@suse.de
- applied a patch that fixes a problem where the package would not
  compile with the --with-perl option.
* Sat Oct 21 2006 schwab@suse.de
- Don't use obsolete macro.
* Fri Oct 13 2006 danw@suse.de
- Remove dead patches
* Thu Oct  5 2006 jhargadon@suse.de
- added --datadir=%%prefix/share as a configuration option.  This
  is a work around for bug #204719
* Fri Sep 29 2006 jhargadon@suse.de
- update to version 0.44.1
- Layers dialog
- Outline mode, many performance improvements
- Native PDF export with transparency
- Clipping and masking support
- Configurable keyboard shortcuts
- Docked color palette in the editing window
- Interactive indicator of the style of selection in the statusbar
- Innovative "node sculpting" and other improvements in Node tool
- Better SVG support: <switch> element, ICC color profiles for images
- Persistent rotation centers, Paste Size command
- many bug fixes
- removed the --with-perl option from configuration in the specfile
* Sat Sep  9 2006 meissner@suse.de
- use RPM_OPT_FLAGS.
* Wed Aug 16 2006 cthiel@suse.de
- buildrequire python-gtk-devel instead of python-gtk
* Fri Jul  7 2006 jpr@suse.de
- add patch to not use freetype2 internals
* Sat Feb 18 2006 stbinner@suse.de
- fix typo .desktop file
* Sat Feb 18 2006 gekker@suse.de
- fixup .desktop file for UI team
* Tue Jan 31 2006 ro@suse.de
- take fix from swig to swig-generated source file
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Nov 23 2005 sbrabec@suse.cz
- Updated to version 0.43 (#134655).
- Enabled Inkboard Collaborative Editing.
* Mon Nov  7 2005 sbrabec@suse.cz
- Fixed qualification and type conversion errors.
* Thu Aug 25 2005 nadvornik@suse.cz
- updated to bugfix release 0.42.2 [#112918]
* Mon Aug  1 2005 ro@suse.de
- added dir to filelist /usr/share/man/fr/man1
* Fri Jul 29 2005 sbrabec@suse.cz
- Updated to version 0.42.
* Tue May 31 2005 schwab@suse.de
- Fix more invalid casts.
* Wed May 18 2005 ro@suse.de
- fix build with current pkgconfig
* Thu Apr 28 2005 sbrabec@suse.cz
- Build boehm-gc with -fPIC and -fno-strict-aliasing.
* Wed Apr 27 2005 ro@suse.de
- remove boehm-gc from nfb (dropped)
- use private copy of gc6.4
* Tue Apr 26 2005 sbrabec@suse.cz
- Install missing translation files.
* Mon Apr 11 2005 sbrabec@suse.cz
- Fixed invalid casts.
* Mon Mar 21 2005 sbrabec@suse.cz
- Bi-arch fix (#66780).
- Require skencil needed for PS/EPS input (#66780).
* Mon Feb 28 2005 sbrabec@suse.cz
- Added needed Requires and triggers for optional extensions
  (#66780).
- Turned on perl, python and gnome-print support.
* Mon Feb 21 2005 sbrabec@suse.cz
- Updated to version 0.41.
- Worked around problems with boehm-gc detection.
* Fri Feb 11 2005 sbrabec@suse.cz
- Updated to version 0.40.
* Fri Feb 11 2005 ro@suse.de
- change to libsigc++12 in neededforbuild
* Tue Nov  2 2004 mmj@suse.de
- Locale rename: no -> nb
* Thu Aug 12 2004 hhetter@suse.de
- Obsolete and Provide sodipodi
* Mon Aug  2 2004 hhetter@suse.de
- initial SuSE package
